summaryrefslogtreecommitdiff
path: root/desktop
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2016-01-26 12:37:20 +0100
committerMichael Stahl <mstahl@redhat.com>2016-01-26 17:51:28 +0100
commit39963be8679ceef5d08eda9e04e97b6fbb079b71 (patch)
tree75337d944e12b0a3833e9093debb4d95ca6b0691 /desktop
parent27feec6f91e464651ede25a955aac5bf75bcacf6 (diff)
vcl: convert boost::shared_array to std::shared_ptr
Change-Id: I9d0ad886c4c6e1c8496eb6129b22d327ca0968eb
Diffstat (limited to 'desktop')
-rw-r--r--desktop/source/lib/init.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/desktop/source/lib/init.cxx b/desktop/source/lib/init.cxx
index d022f6f69ba3..53d84f7d3c60 100644
--- a/desktop/source/lib/init.cxx
+++ b/desktop/source/lib/init.cxx
@@ -101,11 +101,11 @@ typedef struct
const char *filterName;
} ExtensionMap;
// We need a shared_array for passing into the BitmapDevice (via
// VirtualDevice.SetOutputSizePixelScaleOffsetAndBuffer which goes via the
// SvpVirtualDevice, ending up in the cairo surface. However as we're
// given the array externally we can't delete it, and hence need to override
// shared_array's default of deleting its pointer.
template<typename T>
struct NoDelete
{
@@ -924,7 +924,7 @@ void doc_paintTile (LibreOfficeKitDocument* pThis,
pDevice->SetBackground(Wallpaper(Color(COL_TRANSPARENT)));
#endif
- boost::shared_array< sal_uInt8 > aBuffer( pBuffer, NoDelete< sal_uInt8 >() );
+ std::shared_ptr<sal_uInt8> aBuffer( pBuffer, NoDelete<sal_uInt8>() );
pDevice->SetOutputSizePixelScaleOffsetAndBuffer(
Size(nCanvasWidth, nCanvasHeight), Fraction(1.0), Point(),
@@ -1569,7 +1569,7 @@ unsigned char* doc_renderFont(LibreOfficeKitDocument* /*pThis*/,
unsigned char* pBuffer = static_cast<unsigned char*>(malloc(4 * nFontWidth * nFontHeight));
memset(pBuffer, 0, nFontWidth * nFontHeight * 4);
- boost::shared_array<sal_uInt8> aBuffer(pBuffer, NoDelete< sal_uInt8 >());
+ std::shared_ptr<sal_uInt8> aBuffer(pBuffer, NoDelete<sal_uInt8>());
aDevice->SetBackground(Wallpaper(COL_TRANSPARENT));
aDevice->SetOutputSizePixelScaleOffsetAndBuffer(
@@ -101,11 +101,11 @@ typedef struct
const char *filterName;
} ExtensionMap;
-// We need a shared_array for passing into the BitmapDevice (via
+// We need a shared_ptr for passing into the BitmapDevice (via
// VirtualDevice.SetOutputSizePixelScaleOffsetAndBuffer which goes via the
// SvpVirtualDevice, ending up in the cairo surface. However as we're
@@ -101,11 +101,11 @@ typedef struct
// SvpVirtualDevice, ending up in the cairo surface. However as we're
// given the array externally we can't delete it, and hence need to override
-// shared_array's default of deleting its pointer.
+// shared_ptr's default of deleting its pointer.
template<typename T>
struct NoDelete